@@ -18,7 +18,6 @@ from simple_ado.comments import (
     ADOCommentProperty,
     ADOCommentStatus,
 )
-from simple_ado.context import ADOContext
 from simple_ado.exceptions import ADOException
 from simple_ado.git import ADOGitStatusState
 from simple_ado.http_client import ADOHTTPClient, ADOResponse, ADOThread
@@ -29,23 +28,25 @@ from simple_ado.models import PatchOperation, AddOperation, DeleteOperation, Pro
 class ADOPullRequestClient(ADOBaseClient):
     """Wrapper class around the ADO Pull Request APIs.
 
-    :param context: The context information for the client
     :param http_client: The HTTP client to use for the client
     :param log: The logger to use
     :param pull_request_id: The ID of the pull request
+    :param repository_id: The ID of the repository the PR is for
     """
 
     pull_request_id: int
+    repository_id: str
 
     def __init__(
         self,
-        context: ADOContext,
         http_client: ADOHTTPClient,
         log: logging.Logger,
         pull_request_id: int,
+        repository_id: str,
     ) -> None:
         self.pull_request_id = pull_request_id
-        super().__init__(context, http_client, log.getChild(f"pr.{pull_request_id}"))
+        self.repository_id = repository_id
+        super().__init__(http_client, log.getChild(f"pr.{pull_request_id}"))
 
     def details(self) -> ADOResponse:
         """Get the details for the PR from ADO.
@@ -54,9 +55,7 @@ class ADOPullRequestClient(ADOBaseClient):
         """
 
         self.log.debug(f"Getting PR: {self.pull_request_id}")
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}?api-version=3.0-preview"
         response = self.http_client.get(request_url)
         return self.http_client.decode_response(response)
@@ -68,9 +67,7 @@ class ADOPullRequestClient(ADOBaseClient):
         """
 
         self.log.debug(f"Getting workitems: {self.pull_request_id}")
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}/workitems?api-version=5.0"
         response = self.http_client.get(request_url)
         return self.http_client.decode_response(response)
@@ -84,9 +81,7 @@ class ADOPullRequestClient(ADOBaseClient):
         """
 
         self.log.debug(f"Getting threads: {self.pull_request_id}")
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}/threads?api-version=3.0-preview"
         response = self.http_client.get(request_url)
         response_data = self.http_client.decode_response(response)
@@ -118,7 +113,7 @@ class ADOPullRequestClient(ADOBaseClient):
 
         self.log.debug(f"Creating comment: ({self.pull_request_id}) {comment_text}")
         comment = ADOComment(comment_text, comment_location)
-        return self.create_comment(comment, status=status, comment_identifier=comment_identifier)
+        return self.create_comment(comment, status=status, comment_identifier=comment_identifier,)
 
     def create_comment(
         self,
@@ -139,7 +134,7 @@ class ADOPullRequestClient(ADOBaseClient):
 
         self.log.debug(f"Creating comment: ({self.pull_request_id}) {comment}")
         return self.create_thread(
-            [comment.generate_representation()],
+            comments=[comment.generate_representation()],
             thread_location=comment.location,
             status=status,
             comment_identifier=comment_identifier,
@@ -147,8 +142,8 @@ class ADOPullRequestClient(ADOBaseClient):
 
     def create_thread(
         self,
-        comments: List[Dict[str, Any]],
         *,
+        comments: List[Dict[str, Any]],
         thread_location: Optional[ADOCommentLocation] = None,
         status: Optional[ADOCommentStatus] = None,
         comment_identifier: Optional[str] = None,
@@ -166,9 +161,7 @@ class ADOPullRequestClient(ADOBaseClient):
 
         self.log.debug(f"Creating thread ({self.pull_request_id})")
 
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}/threads?api-version=3.0-preview"
 
         properties = {
@@ -205,9 +198,7 @@ class ADOPullRequestClient(ADOBaseClient):
         for comment in thread["comments"]:
             comment_id = comment["id"]
             self.log.debug(f"Deleting comment: {comment_id}")
-            request_url = (
-                f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-            )
+            request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
             request_url += f"/pullRequests/{self.pull_request_id}/threads/{thread_id}"
             request_url += f"/comments/{comment_id}?api-version=3.0-preview"
             requests.delete(
@@ -217,7 +208,7 @@ class ADOPullRequestClient(ADOBaseClient):
             )
 
     def create_thread_list(
-        self, threads: List[ADOComment], comment_identifier: Optional[str] = None
+        self, *, threads: List[ADOComment], comment_identifier: Optional[str] = None,
     ) -> None:
         """Create a list of threads
 
@@ -244,6 +235,7 @@ class ADOPullRequestClient(ADOBaseClient):
         state: ADOGitStatusState,
         identifier: str,
         description: str,
+        context: str,
         *,
         iteration: Optional[int] = None,
         target_url: Optional[str] = None,
@@ -253,6 +245,7 @@ class ADOPullRequestClient(ADOBaseClient):
         :param ADOGitStatusState state: The state to set the status to.
         :param str identifier: A unique identifier for the status (so it can be changed later)
         :param str description: The text to show in the status
+        :param str context: The context for the build status
         :param Optional[int] iteration: The iteration of the PR to set the status on
         :param Optional[str] target_url: An optional URL to set which is opened when the description is clicked.
 
@@ -263,15 +256,13 @@ class ADOPullRequestClient(ADOBaseClient):
             f"Setting PR status ({state}) on PR ({self.pull_request_id}): {identifier} -> {description}"
         )
 
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}/statuses?api-version=4.0-preview"
 
         body = {
             "state": state.value,
             "description": description,
-            "context": {"name": self.context.status_context, "genre": identifier},
+            "context": {"name": context, "genre": identifier},
         }
 
         if iteration is not None:
@@ -294,6 +285,8 @@ class ADOPullRequestClient(ADOBaseClient):
         :raises ADOException: If we couldn't find the author or the properties
         """
 
+        _ = self
+
         try:
             # Deleted threads can stay around if they have other comments, so we
             # check if it was deleted before we check anything else.
@@ -303,15 +296,6 @@ class ADOPullRequestClient(ADOBaseClient):
             # If it's not there, it's not set
             pass
 
-        try:
-            # It wasn't one of the specified users comments
-            if thread["comments"][0]["author"]["uniqueName"] != self.context.username:
-                return False
-        except:
-            raise ADOException(
-                "Could not find comments.0.author.uniqueName in thread: " + str(thread)
-            )
-
         try:
             properties = thread["properties"]
         except:
@@ -368,7 +352,7 @@ class ADOPullRequestClient(ADOBaseClient):
 
         for thread in self.threads_with_identifier(identifier):
             self.log.debug(f"Deleting thread: {thread}")
-            self.delete_thread(thread)
+            self.delete_thread(thread=thread)
 
     def get_properties(self) -> Dict[str, PropertyValue]:
         """Get the properties on the PR from ADO.
@@ -377,9 +361,7 @@ class ADOPullRequestClient(ADOBaseClient):
         """
 
         self.log.debug(f"Getting properties: {self.pull_request_id}")
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}/properties?api-version=5.1-preview.1"
         response = self.http_client.get(request_url)
         response_data = self.http_client.decode_response(response)
@@ -401,9 +383,7 @@ class ADOPullRequestClient(ADOBaseClient):
         """
 
         self.log.debug(f"Patching properties: {self.pull_request_id}")
-        request_url = (
-            f"{self.http_client.api_endpoint()}/git/repositories/{self.context.repository_id}"
-        )
+        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{self.repository_id}"
         request_url += f"/pullRequests/{self.pull_request_id}/properties?api-version=5.1-preview.1"
 
         response = self.http_client.patch(request_url, operations=operations)
