@@ -13,7 +13,6 @@ import urllib.parse
 
 
 from simple_ado.base_client import ADOBaseClient
-from simple_ado.context import ADOContext
 from simple_ado.exceptions import ADOException
 from simple_ado.http_client import ADOHTTPClient, ADOResponse
 from simple_ado.types import TeamFoundationId
@@ -63,39 +62,47 @@ class ADOBranchPolicy(enum.Enum):
 class ADOSecurityClient(ADOBaseClient):
     """Wrapper class around the undocumented ADO Security APIs.
 
-    :param context: The context information for the client
     :param http_client: The HTTP client to use for the client
     :param log: The logger to use
     """
 
     GIT_PERMISSIONS_NAMESPACE: ClassVar[str] = "2e9eb7ed-3c0a-47d4-87c1-0ffdd275fd87"
 
-    def __init__(
-        self, context: ADOContext, http_client: ADOHTTPClient, log: logging.Logger
-    ) -> None:
-        super().__init__(context, http_client, log.getChild("security"))
+    def __init__(self, http_client: ADOHTTPClient, log: logging.Logger) -> None:
+        super().__init__(http_client, log.getChild("security"))
 
-    def get_policies(self) -> ADOResponse:
+    def get_policies(self, project_id: str) -> ADOResponse:
         """Gets the existing policies.
 
+        :param project_id: The identifier for the project
+
         :returns: The ADO response with the data in it
         """
-
-        request_url = f"{self.http_client.api_endpoint(is_project=True)}/policy/Configurations?api-version=5.0"
+        request_url = (
+            self.http_client.api_endpoint(is_project=True, project_id=project_id)
+            + "/policy/Configurations?api-version=5.0"
+        )
         response = self.http_client.get(request_url)
         response_data = self.http_client.decode_response(response)
         return self.http_client.extract_value(response_data)
 
-    def add_branch_build_policy(self, branch: str, *, build_definition_id: int) -> ADOResponse:
+    def add_branch_build_policy(
+        self, *, branch: str, build_definition_id: int, project_id: str, repository_id: str,
+    ) -> ADOResponse:
         """Adds a new build policy for a given branch.
 
         :param str branch: The git branch to set the build policy for
         :param int build_definition_id: The build definition to use when creating the build policy
+        :param str project_id: The identifier for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
         """
 
-        request_url = f"{self.http_client.api_endpoint(is_project=True)}/policy/Configurations?api-version=5.0"
+        request_url = (
+            self.http_client.api_endpoint(is_project=True, project_id=project_id)
+            + "/policy/Configurations?api-version=5.0"
+        )
 
         body = {
             "type": {"id": ADOBranchPolicy.BUILD.value},
@@ -113,7 +120,7 @@ class ADOSecurityClient(ADOBaseClient):
                     {
                         "refName": f"refs/heads/{branch}",
                         "matchKind": "Exact",
-                        "repositoryId": self.context.repository_id,
+                        "repositoryId": repository_id,
                     }
                 ],
             },
@@ -123,18 +130,23 @@ class ADOSecurityClient(ADOBaseClient):
         return self.http_client.decode_response(response)
 
     def add_branch_required_reviewers_policy(
-        self, branch: str, *, identities: List[str]
+        self, *, branch: str, identities: List[str], project_id: str, repository_id: str,
     ) -> ADOResponse:
         """Adds required reviewers when opening PRs against a given branch.
 
         :param str branch: The git branch to set required reviewers for
         :param List[str] identities: A list of identities to become required
                                      reviewers (should be team foundation IDs)
+        :param str project_id: The identifier for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
         """
 
-        request_url = f"{self.http_client.api_endpoint(is_project=True)}/policy/Configurations?api-version=5.0"
+        request_url = (
+            self.http_client.api_endpoint(is_project=True, project_id=project_id)
+            + "/policy/Configurations?api-version=5.0"
+        )
 
         body = {
             "type": {"id": ADOBranchPolicy.REQUIRED_REVIEWERS.value},
@@ -152,7 +164,7 @@ class ADOSecurityClient(ADOBaseClient):
                     {
                         "refName": f"refs/heads/{branch}",
                         "matchKind": "Exact",
-                        "repositoryId": self.context.repository_id,
+                        "repositoryId": repository_id,
                     }
                 ],
             },
@@ -163,11 +175,13 @@ class ADOSecurityClient(ADOBaseClient):
 
     def set_branch_approval_count_policy(
         self,
-        branch: str,
         *,
+        branch: str,
         minimum_approver_count: int,
         creator_vote_counts: bool = False,
         reset_on_source_push: bool = False,
+        project_id: str,
+        repository_id: str,
     ) -> ADOResponse:
         """Set minimum number of reviewers for a branch.
 
@@ -175,11 +189,16 @@ class ADOSecurityClient(ADOBaseClient):
         :param int minimum_approver_count: The minimum number of approvals required
         :param bool creator_vote_counts: Allow users to approve their own changes
         :param bool reset_on_source_push: Reset reviewer votes when there are new changes
+        :param str project_id: The identifier for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
         """
 
-        request_url = f"{self.http_client.api_endpoint(is_project=True)}/policy/Configurations?api-version=5.0"
+        request_url = (
+            self.http_client.api_endpoint(is_project=True, project_id=project_id)
+            + "/policy/Configurations?api-version=5.0"
+        )
 
         body = {
             "type": {"id": ADOBranchPolicy.APPROVAL_COUNT.value},
@@ -195,7 +214,7 @@ class ADOSecurityClient(ADOBaseClient):
                     {
                         "refName": f"refs/heads/{branch}",
                         "matchKind": "exact",
-                        "repositoryId": self.context.repository_id,
+                        "repositoryId": repository_id,
                     }
                 ],
             },
@@ -204,16 +223,23 @@ class ADOSecurityClient(ADOBaseClient):
         response = self.http_client.post(request_url, json_data=body)
         return self.http_client.decode_response(response)
 
-    def set_branch_work_item_policy(self, branch: str, *, required: bool = True) -> ADOResponse:
+    def set_branch_work_item_policy(
+        self, *, branch: str, required: bool = True, project_id: str, repository_id: str,
+    ) -> ADOResponse:
         """Set the work item policy for a branch.
 
         :param str branch: The git branch to set the work item policy on
         :param bool required: Whether or not linked work items should be mandatory
+        :param str project_id: The identifier for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
         """
 
-        request_url = f"{self.http_client.api_endpoint(is_project=True)}/policy/Configurations?api-version=5.0"
+        request_url = (
+            self.http_client.api_endpoint(is_project=True, project_id=project_id)
+            + "/policy/Configurations?api-version=5.0"
+        )
 
         body = {
             "type": {"id": ADOBranchPolicy.WORK_ITEM.value},
@@ -226,7 +252,7 @@ class ADOSecurityClient(ADOBaseClient):
                     {
                         "refName": f"refs/heads/{branch}",
                         "matchKind": "Exact",
-                        "repositoryId": self.context.repository_id,
+                        "repositoryId": repository_id,
                     }
                 ]
             },
@@ -237,23 +263,34 @@ class ADOSecurityClient(ADOBaseClient):
 
     def set_branch_permissions(
         self,
-        branch: str,
         *,
+        branch: str,
         identity: TeamFoundationId,
         permissions: Dict[ADOBranchPermission, ADOBranchPermissionLevel],
+        project_id: str,
+        repository_id: str,
     ) -> ADOResponse:
         """Set permissions for an identity on a branch.
 
         :param str branch: The git branch to set permissions on
         :param TeamFoundationId identity: The identity to set permissions for (should be team foundation ID)
         :param Dict[ADOBranchPermission,ADOBranchPermissionLevel] permissions: A dictionary of permissions to set
+        :param str project_id: The identifier for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The ADO response with the data in it
         """
 
-        descriptor_info = self._get_descriptor_info(branch, identity)
+        descriptor_info = self._get_descriptor_info(
+            branch=branch,
+            team_foundation_id=identity,
+            project_id=project_id,
+            repository_id=repository_id,
+        )
 
-        request_url = self.http_client.api_endpoint(is_project=True, is_internal=True)
+        request_url = self.http_client.api_endpoint(
+            is_project=True, is_internal=True, project_id=project_id
+        )
         request_url += "/_security/ManagePermissions?__v=5"
 
         updates = []
@@ -263,7 +300,9 @@ class ADOSecurityClient(ADOBaseClient):
                     "PermissionId": level,
                     "PermissionBit": permission,
                     "NamespaceId": ADOSecurityClient.GIT_PERMISSIONS_NAMESPACE,
-                    "Token": self._generate_updates_token(branch),
+                    "Token": self._generate_updates_token(
+                        branch=branch, project_id=project_id, repository_id=repository_id
+                    ),
                 }
             )
 
@@ -273,7 +312,9 @@ class ADOSecurityClient(ADOBaseClient):
             "DescriptorIdentityType": descriptor_info["type"],
             "DescriptorIdentifier": descriptor_info["id"],
             "PermissionSetId": ADOSecurityClient.GIT_PERMISSIONS_NAMESPACE,
-            "PermissionSetToken": self._generate_permission_set_token(branch),
+            "PermissionSetToken": self._generate_permission_set_token(
+                branch=branch, project_id=project_id, repository_id=repository_id
+            ),
             "RefreshIdentities": False,
             "Updates": updates,
             "TokenDisplayName": None,
@@ -285,25 +326,36 @@ class ADOSecurityClient(ADOBaseClient):
         return self.http_client.decode_response(response)
 
     def _get_descriptor_info(
-        self, branch: str, team_foundation_id: TeamFoundationId
+        self,
+        *,
+        branch: str,
+        team_foundation_id: TeamFoundationId,
+        project_id: str,
+        repository_id: str,
     ) -> Dict[str, str]:
         """Fetch the descriptor identity information for a given identity.
 
         :param str branch: The git branch of interest
         :param TeamFoundationId team_foundation_id: the unique Team Foundation GUID for the identity
+        :param project_id: The identifier for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The raw descriptor info
 
         :raises ADOException: If we can't determine the descriptor info from the response
         """
 
-        request_url = self.http_client.api_endpoint(is_project=True, is_internal=True)
+        request_url = self.http_client.api_endpoint(
+            is_project=True, is_internal=True, project_id=project_id
+        )
         request_url += "/_security/DisplayPermissions?"
 
         parameters = {
             "tfid": team_foundation_id,
             "permissionSetId": ADOSecurityClient.GIT_PERMISSIONS_NAMESPACE,
-            "permissionSetToken": self._generate_permission_set_token(branch),
+            "permissionSetToken": self._generate_permission_set_token(
+                branch=branch, project_id=project_id, repository_id=repository_id
+            ),
             "__v": "5",
         }
 
@@ -325,27 +377,36 @@ class ADOSecurityClient(ADOBaseClient):
 
         return descriptor_info
 
-    def _generate_permission_set_token(self, branch: str) -> str:
+    def _generate_permission_set_token(
+        self, branch: str, project_id: str, repository_id: str,
+    ) -> str:
         """Generate the token required for reading identity details and writing permissions.
 
         :param str branch: The git branch of interest
+        :param str project_id: The ID for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The permission token
         """
+        _ = self
         encoded_branch = branch.replace("/", "^")
-        return f"repoV2/{self.http_client.project_id}/{self.context.repository_id}/refs^heads^{encoded_branch}/"
+        return f"repoV2/{project_id}/{repository_id}/refs^heads^{encoded_branch}/"
 
-    def _generate_updates_token(self, branch: str) -> str:
+    def _generate_updates_token(self, branch: str, project_id: str, repository_id: str,) -> str:
         """Generate the token required for updating permissions.
 
         :param str branch: The git branch of interest
+        :param str project_id: The ID for the project
+        :param str repository_id: The ID for the repository
 
         :returns: The update token
         """
 
+        _ = self
+
         # Encode each node in the branch to hex
         encoded_branch_nodes = [node.encode("utf-16le").hex() for node in branch.split("/")]
 
         encoded_branch = "/".join(encoded_branch_nodes)
 
-        return f"repoV2/{self.http_client.project_id}/{self.context.repository_id}/refs/heads/{encoded_branch}/"
+        return f"repoV2/{project_id}/{repository_id}/refs/heads/{encoded_branch}/"
